package es.guia.db;

import java.util.*;

import es.guia.interfaz.Menus;
import es.guia.interfaz.R;
import android.content.Context;
import android.content.res.AssetManager;
import android.content.res.Resources;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteDatabase.CursorFactory;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

import es.guia.util.*;
import es.guia.beans.*;

public class GuiaDatabaseHelper extends SQLiteOpenHelper {
	public static final String TIPO_POI="TIPO_POI"; //Tipologa del punto de inters
	public static final String POI="POI"; //Puntos de inters de la aplicacin
	public static final String GALERIA="GALERIA"; //Galeria relacionada con el punto de inters
	public static final String DATABASE_NAME="guia";
	public static final int DATABASE_VERSION=3;
	
	private Context context=null;
	
	public GuiaDatabaseHelper(Context context, String databaseName, CursorFactory factory, int version) {
		super(context, databaseName, factory, version);
		this.context=context;
		
		Log.d("Guia","Constructor GuiaDatabaseHelper");
	}
	
	public GuiaDatabaseHelper(Context context){
		super(context,DATABASE_NAME,null,DATABASE_VERSION);
		this.context=context;
	}

	@Override
	public void onCreate(SQLiteDatabase db) {
		
		
		Log.d("Guia","Ejecutando el script de creacion");
		
		//Script completo de creacin de BBDD.
		db.execSQL("CREATE  TABLE \""+TIPO_POI+"\" (\"ID\" INTEGER PRIMARY KEY  AUTOINCREMENT NOT NULL , \"NOMBRE\" VARCHAR NOT NULL  UNIQUE );");
		db.execSQL("CREATE  TABLE \""+POI+"\" (\"id\" INTEGER PRIMARY KEY  AUTOINCREMENT NOT NULL , \"nombre\" VARCHAR NOT NULL , \"latitud\" DOUBLE, \"longitud\" DOUBLE, \"imagen\" VARCHAR, \"desc_breve\" VARCHAR, \"desc_larga\" VARCHAR,\"precio\" VARCHAR,\"horario\" VARCHAR ,tipo_poi INTEGER, FOREIGN KEY(tipo_poi) REFERENCES TIPO_POI (id));");
		db.execSQL("CREATE  TABLE \""+GALERIA+"\" (\"ID\" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL , \"IMAGEN\" VARCHAR NOT NULL, id_poi INTEGER, FOREIGN KEY(id_poi) REFERENCES ID_POI (id));");
		
		
		//Datos pre-almacenados
		db.execSQL("insert into "+TIPO_POI+" (nombre) values ('Museo')");
		db.execSQL("insert into "+TIPO_POI+" (nombre) values ('Monumento')");
		db.execSQL("insert into "+TIPO_POI+" (nombre) values ('Restaurante')");
		db.execSQL("insert into "+TIPO_POI+" (nombre) values ('Usuario')");
		
		//Puntos de inters catalogados
		if(context.getResources().getXml(R.xml.lista_pois)==null) Log.i("Guia", "El xmlresources es nulo");
		XMLReaderHelper xmlHelper=new XMLReaderHelper(context.getResources().getXml(R.xml.lista_pois));
		Vector<POI> listaPOIs=xmlHelper.getPOIs();
		
		for(int i=0;i<listaPOIs.size();i++){
			POI p=listaPOIs.elementAt(i);
			String sql="insert into "+POI+" (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_poi,precio,horario) values "
				+"('"+p.getNombre()+"'"
				+","+p.getLongitud()
				+","+p.getLatitud()
				+",'"+p.getImagen()+"'"
				+",'"+p.getDesc_breve()+"'"
				+",'"+p.getDesc_larga()+"'"
				+","+p.getTipoPOI()
				+",'"+p.getPrecio()+"'"
				+",'"+p.getHorario()+"'"
				+")";
			
			db.execSQL(sql);
			
			//Insercin de imgenes asociadas
			Vector<String> galeria=p.getImagenesGaleria();
			
			for(int k=0;k<galeria.size();k++){
				String imagen=galeria.elementAt(k);
				sql="insert into "+GALERIA+" (imagen,id_poi)  values "
					+"('"+imagen+"'"
					+","+(i+1)+")";
				
				db.execSQL(sql);
				Log.i("Guia","insertada la imagen: "+imagen+" asociada al POI: "+p.getNombre());
			}
			
		}
		
		/*
		StringBuffer prado=new StringBuffer();
		prado.append("El Museo Nacional del Prado, ubicado en Madrid, Espaa, es uno de los ms importantes y ms visitados del mundo (el noveno en 2009). Singularmente rico en cuadros de maestros europeos de los" +
				" siglos XVI al XIX, su principal atractivo radica en la amplia presencia de Velzquez, El Greco, Goya (el artista ms extensamente representado en la coleccin),2 Tiziano, Rubens y El Bosco, de los " +
				"que posee las mejores colecciones que existen a nivel mundial, a lo que hay que sumar destacados conjuntos de autores tan importantes como Murillo, Ribera, Zurbarn, Rafael, Veronese, Tintoretto o Van Dyck, por citar slo los ms relevantes. Por crnicas limitaciones de espacio, el museo exhiba una seleccin muy restringida de obras de mxima calidad (unas 900), por lo que era definido como la mayor concentracin de obras maestras por metro cuadrado. Con la reciente ampliacin de Rafael Moneo, se previ que la seleccin expuesta crecera en un 50%, con unas 450 obras ms.3 En julio de 2011, muy avanzada la reorganizacin de las salas, la exhibicin permanente ha sumado unas 300 obras, por lo que el total expuesto llega a 1.150, de un inventario de ms de 7.900. Adems de las pinturas el Prado posee alrededor de 950 esculturas, 6.400 dibujos, 2.400 grabados, 800 objetos de artes decorativas, 900 monedas y 800 medallas.4 " +
				"Al igual que otros grandes museos europeos, como el Louvre de Pars y los Uffizi de Florencia, el Prado debe su origen a la aficin coleccionista de las dinastas gobernantes a lo largo de varios siglos. Refleja los gustos personales de los reyes espaoles y su red de alianzas y sus enemistades polticas, por lo que es una coleccin asimtrica, insuperable en determinados artistas y estilos, y dbil en otros. Slo desde el siglo XX se procura, con resultados desiguales, solventar las ausencias ms notorias. " +
				"El Prado no es un museo enciclopdico al estilo del Museo del Louvre, la National Gallery de Londres, o incluso (a una escala mucho ms reducida) el vecino Museo Thyssen-Bornemisza, que tienen obras de prcticamente todas las escuelas y pocas. Por el contrario, es una coleccin intensa y distinguida, formada esencialmente por unos pocos reyes aficionados al Arte, donde muchas obras fueron creadas por encargo. El ncleo procedente de la Coleccin Real se ha ido complementando con aportaciones posteriores, que apenas han desdibujado su perfil inicial. Muchos expertos la consideran una coleccin de pintores admirados por pintores, enseanza inagotable para nuevas generaciones de artistas, desde Manet, Renoir y Toulouse-Lautrec, que visitaron el museo en el siglo XIX, hasta Picasso, Matisse, Dal, Francis Bacon y Antonio Saura, quien deca: Este museo no es el ms extenso, pero s el ms intenso.5 " +
				"Las escuelas pictricas de Espaa, Flandes e Italia (sobre todo Venecia) ostentan el protagonismo en el Prado, seguidas por el fondo francs, ms limitado si bien incluye buenos ejemplos de Nicolas Poussin y Claudio de Lorena. La pintura alemana cuenta con un repertorio discontinuo, con cuatro obras de Durero y mltiples retratos de Mengs como principales tesoros. Junto con un repertorio britnico limitado, circunscrito casi al gnero del retrato, hay que mencionar la pintura holandesa, una seccin no demasiado amplia pero que incluye a Rembrandt. " +
				"Aunque sean aspectos menos conocidos, cuenta tambin con una importante seccin de Artes decorativas (Tesoro del Delfn) y con una destacada coleccin de esculturas greco-romanas. Junto con el Museo Thyssen-Bornemisza y el Museo Reina Sofa, el Museo Nacional del Prado forma el Tringulo del Arte, meca de numerosos turistas de todo el mundo. Esta rea se enriquece con otras instituciones cercanas: el Museo Arqueolgico Nacional, el Museo Nacional de Artes Decorativas, la Real Academia de Bellas Artes de San Fernando y otros pequeos museos.");
		
		StringBuffer palacio=new StringBuffer(); 
		palacio.append("El Palacio Real de Madrid es la residencia oficial de Su Majestad el Rey de Espaa, que lo emplea en las ceremonias de Estado, aunque no habita en l." +
     		"El origen del palacio se remonta al siglo IX en el que el reino musulmn de Toledo construy una edificacin defensiva que despus usaron los reyes de Castilla, sobre la que en el Siglo XVI, se construy el Antiguo Alczar." +
     		"Destruido este por un incendio en la Nochebuena de 1734, Felipe V quiso que el Palacio Nuevo ocupase el mismo lugar. Toda la construccin se hizo abovedada, en piedra y ladrillo, sin madera, para que ningn incendio pudiera destruirlo." +
     		"Las obras se realizaron entre 1738 y 1755, estableciendo Carlos III su residencia en l en 1764. Para su decoracin interior, se emplearon ricos materiales: mrmoles espaoles, estucos, madera de caoba en puertas y ventanas e importantes obras de arte, en especial las pinturas al fresco de los principales artistas del momento como Giaquinto,Tiepolo o Mengs y sus seguidores espaoles Bayeu y Maella." +
     		"La decoracin del Palacio Real de Madrid ha ido cambiando con el paso del tiempo segn los diferentes estilos artsticos de cada momento. Del reinado de Carlos III se conservan el Saln del Trono, la Cmara del Rey (o de Gasparini) y la Sala de Porcelana, obra de la Real Fbrica del Buen Retiro. Del reinado de Carlos IV destaca el Saln de Espejos y de poca Alfonso XII el Comedor de Gala. ");
		
		StringBuffer elretiro=new StringBuffer(); 
		elretiro.append("Los jardines tienen su origen entre los aos 1630 y 1640, cuando el Conde-Duque de Olivares (Gaspar de Guzmn y Pimentel), " +
     		"valido de Felipe IV (16211665), le regal al Rey unos terrenos que le haban sido cedidos por el duque de Fernn Nez para el recreo de " +
     		"la Corte en torno al Monasterio de los Jernimos de Madrid. As, con la reforma del Cuarto Real que haba junto al monasterio, se inici " +
     		"la construccin del Palacio del Buen Retiro. Contaba entonces con unas 145 hectreas. Aunque esta segunda residencia real iba a estar en " +
     		"lo que en aquellos tiempos eran las afueras de la villa de Madrid, no estaba excesivamente lejos del Real Alczar y result ser un lugar " +
     		"muy agradable, por estar en una zona muy boscosa y fresca. El Casn del Buen Retiro desde el Parque. Parque del Retiro en invierno. Bajo " +
     		"la direccin de los arquitectos Giovanni Battista Crescenzi y Alonso Carbonell se construyeron diversos edificios, entre ellos el Teatro " +
     		"del Buen Retiro, que acogi representaciones de los dramaturgos espaoles del Siglo de Oro, entre ellos Caldern de la Barca y Lope de Vega." +
     		" Perduran an el Casn del Buen Retiro, antiguo Saln de Baile con frescos de Lucas Jordn, y el llamado Saln de Reinos, un ala del Palacio del " +
     		"Buen Retiro decorado antao con pinturas de Velzquez y Zurbarn, entre otros; y los jardines de la posesin real. stos se formaron al mismo tiempo " +
     		"que el palacio, trabajando en ellos, entre otros, Cosme Lotti, escengrafo del Gran Duque de Toscana, y edificndose una leonera para la exhibicin de animales salvajes y una pajarera de aves exticas. El Estanque grande, escenario " +
     		"de naumaquias y espectculos acuticos, el Estanque ochavado o de las campanillas y la Ra chica pertenecen a este perodo inicial. A lo largo de " +
     		"la historia, el conjunto sufri modificaciones, no siempre planificadas, que cambiaron la fisonoma del jardn, como el Parterre, diseado durante" +
     		" el reinado de Felipe V (17001746), la Real Fbrica de Porcelana del Buen Retiro en tiempos de Carlos III (17591788) o el Observatorio Astronmico, obra de Juan de Villanueva, reinando Carlos IV (17881808). " +
     		"El rey Carlos III fue el primero en permitir el acceso de los ciudadanos al recinto, siempre que cumpliesen con la condicin de ir bien aseados y vestidos. Durante la invasin francesa, en 1808, los jardines quedaron parcialmente " +
     		"destruidos al ser utilizados como fortificacin por las tropas de Napolen. El palacio fue casi totalmente destruido. Tras la contienda, Fernando VII (18141833) inici su reconstruccin y abri una parte del jardn al pueblo, como ya hiciera Carlos III." +
     		" El monarca se reserv una zona, entre las calles de ODonnell y Menndez Pelayo, donde construy una serie de edificios de recreo siguiendo la moda paisajstica de la poca, conservndose an a (principios del siglo XXI) la Casita del pescador, la Casa del " +
     		"contrabandista y la Montaa artificial. Reinando Isabel II (18331868) se abri la calle de Granada, que ms tarde se llamara de Alfonso XII, vendindose al estado los terrenos comprendidos entre sta y el Paseo del Prado que fueron urbanizados por particulares. " +
     		"Tras la revolucin de 1868, (la Gloriosa), los jardines pasan a ser propiedad municipal y sus puertas se abrieron a todos los ciudadanos, comenzando una poca en la cual, la Ra grande y el Estanque de san Antonio de los Portugueses se transformaron en Paseo de Coches. " +
     		"Se colocaron las fuentes de los Galpagos y de la Alcachofa, erigindose tambin la fuente del ngel Cado en lo que fueron terrenos de la Fbrica de Porcelanas, obra de Ricardo Bellver. En el Campo Grande se edificaron el Palacio de Cristal y el Palacio de Velzquez, obra de Ricardo Velzquez Bosco. " +
     		"En esta poca, concretamente a finales del siglo XIX, transcurre la novela que Po Baroja titul Los Jardines del Buen Retiro, en la que se narra la vida de la capital en torno a este enclave. Las ltimas obras de ajardinamiento fueron las ejecutadas por el jardinero " +
     		"mayor Cecilio Rodrguez, que dise la rosaleda y los jardines que llevan su nombre.");
		
		 StringBuffer sol=new StringBuffer(); 
     sol.append("La Puerta del Sol fue en sus orgenes uno de los accesos de la cerca que rodeaba Madrid en el siglo XV. Esta cerca recoga en su permetro los arrabales medievales que haban ido creciendo extramuros, en torno a la muralla cristiana del siglo XII. El nombre de la puerta proviene de un sol que adornaba la entrada, colocado ah por estar orientada la puerta hacia levante. Entre los edificios que le daban prestigio en los comienzos se encontraba Iglesia del Buen Suceso y San Felipe el Real." +
     		"Aunque desde los siglos XVII al XIX la puerta tena importancia como lugar de encuentro (aqu se encontraba uno de los mentideros ms famosos de la villa desde el Siglo de Oro, las famosas gradas de San Felipe), no era una plaza definida, como la Plaza Mayor, y ocupaba la mitad del espacio actual. La Casa de Correos fue construida por el arquitecto francs Jaime Marquet entre 1766 y 1768; la misma fue posteriormente Ministerio de la Gobernacin (Interior) y Direccin General de Seguridad del Estado durante la dictadura franquista y, actualmente, es sede de la Presidencia de la Comunidad de Madrid. Ser esta Casa de Correos la que empiece a sentar las bases urbansticas de lo que hoy es la Puerta del Sol y su creciente importancia como punto cntrico de Madrid. Tras la conversin de la Casa de Correos en sede del Ministerio de Gobernacin (1847), se decide derribar algunas casas de la zona para realzar el edificio y darle seguridad. El resultado sera la creacin de una gran plaza. " +
     		"Para ello, en aplicacin de las leyes de desamortizacin de Mendizbal, se derriban, entre otros, los conventos de San Felipe y Nuestra Seora de las Victorias all ubicados. Entre 1857 y 1862, Lucio del Valle, Juan Rivera y Jos Morer llevan a cabo la reforma de la plaza, dndole su fisonoma actual. Para ello mantienen la alineacin de la Casa de Correos en uno de los lados y construyen edificios de viviendas con fachadas uniformes definiendo un espacio de forma semicircular. " +
     		"En 1959 es reformada por Manuel Herrero Palacios incorporando en su centro una zona ajardinada y las fuentes. En 1986 los arquitectos Antonio Riviere, Javier Ortega y Antonio Gonzlez Capitel introducen una nueva reforma, adquiriendo ms importancia la zona peatonal. Las farolas instaladas con motivo de esta remodelacin, fueron apodadas popularmente como los supositorios y provocaron una gran polmica debido a su diseo moderno. Finalmente fueron sustituidas por las actuales farolas de estilo \"fernandino\", si bien en los dos postes centrales de la plaza los supositorios pervivieron algunos aos ms, para ser unificadas unos aos ms tarde con las del resto de la plaza. " +
     		"Entre 2004 y 2009 se realizaron las obras de construccin de un intercambiador de transportes, inaugurado el 27 de junio de 2009, que acerca la red ferroviaria de Cercanas a la estacin subterrnea de Sol. La estacin se ha convertido por sus dimensiones en la ms grande del mundo1 con 28 m de profundidad, 207 m de longitud y 20 m de ancho. Su vestbulo tiene 7500 m. La entrada al intercomunicador, parecida a un igl ha vuelto a cambiar la fisonoma de la Puerta del Sol. " +
     		"El 15 de Mayo de 2011, tras una manifestacin convocada por la plataforma Democracia Real Ya, decenas de manifestantes acamparon en la plaza esa misma noche, sumndose cada da ms personas y siendo millares durante la semana siguiente, reclamando un cambio poltico, social y econmico en Espaa. Se convierte as la plaza en el smbolo del Movimiento 15M. El da 2 de Agosto, la Polica Nacional desaloja a los ltimos acampados y establece un Estado policial en la Puerta del Sol, impuesto por la Delegada del Gobierno en Madrid (Ministerio del Interior de Espaa) y el Ayuntamiento de Madrid, dnde se impide la libertad de trnsito, de reunin y manifestacin, impidiendo la entrada a la plaza y cerrando las estaciones de metro y cercanas. Manifestantes el da 20 de Mayo de 2011. " +
     		"Edificios representativos y elementos ornamentales. Hitos importantes en esta plaza, aparte de la placa correspondiente al mencionado Kilmetro Cero frente a la Casa de Correos, son la Estatua del Oso y el Madroo, popular punto de encuentro de los madrileos, erigida en 1967 enfrente del edificio de To Pepe, posteriormente trasladada a la boca de la calle del Carmen y reubicada en su lugar original el 25 de septiembre de 20092 ; sendas placas en la fachada de la Casa de Correos, dedicadas, una a los hroes del levantamiento popular del 2 de Mayo y la otra a las vctimas de los atentados del 11 de marzo de 2004 y a las personas que colaboraron el da de la catstrofe; la Estatua de la Mariblanca, reproduccin de una antigua y popular escultura que adornaba la fuente que all exista; y el cartel publicitario de nen de los vinos To Pepe creado por el burgales Luis Prez Solero, ltimo superviviente de los numerosos anuncios que en otros tiempos haba en esta plaza. La Puerta del sol se ve rodeada de catorce edificios. " +
     		"De la misma poca data la medida de 635,50 metros sobre el nivel medio del mar de Alicante. El ltimo elemento aadido, en 1994, es la estatua ecuestre de Carlos III. Para elegir su emplazamiento fue convocado un referndum popular, que tuvo lugar en la propia Puerta del Sol, colocando la estatua, provisionalmente durante el perodo del referndum, en el lugar que ms o menos hoy ocupa. Es una reproduccin en bronce de Miguel ngel Rodrguez y Eduardo Zancada de la obra de Juan Pascual de Mena que se conserva en la Real Academia de Bellas Artes de San Fernando. La inscripcin en espiral que rodea el pedestal describe brevemente la historia del reinado de Carlos III. El monumento mide nueve metros de altura. ");
			
		StringBuffer cibeles=new StringBuffer(); 
     cibeles.append("Originalmente una diosa frigia, Cibeles (en griego antiguo Kybl, nombre al que a veces se da la etimologa de la del pelo si se considera griego en lugar de frigio) era la diosa de la Madre Tierra que fue adorada en Anatolia desde el neoltico. Como la Gea o su equivalente minoica Rea, Cibeles era la personificacin de la frtil tierra, una diosa de las cavernas y las montaas, murallas y fortalezas, de la Naturaleza y los animales (especialmente leones y abejas). Su equivalente romana era Magna Mater, la Gran Madre. Su ttulo Seora de los Animales, que tambin ostentaba la Gran Madre minoica, revela sus arcaicas races paleolticas. Es una deidad de vida, muerte y resurreccin. Su consorte, cuyo culto fue introducido ms tarde, era Atis. " +
     		"Se la representa con una corona con forma de muralla y siempre acompaada de leones. Esta diosa es representada en la mitologa sobre un carro que simboliza la superioridad de la madre Naturaleza, a la que incluso se subordinan los poderosos leones que tiran del carro. La leyenda los relaciona con una singular pareja mitolgica, Hipmenes (Melanin, en otras versiones) y Atalanta, que compitieron en una carrera de velocidad. La astucia de Hipmenes -inspirado por la diosa del amor, ya que el premio era la mano de Atalanta- hizo caer al suelo unas manzanas de oro que atrajeron la atencin de Atalanta y la distrajeron de la carrera, que perdi. El mito concluye con la unin impa de los amantes dentro de un recinto sagrado de Zeus, quien, irritado, los convirti en leones. Ms tarde Cibeles, compadecida, los habra uncido a su carro." +
     		"Adicionalmente, para iniciar el culto como sacerdote de Cibeles, stos eran castrados como una contribucin a la madre tierra; adems hacan un sacrificio matando toros y bebiendo su sangre.");
	
	StringBuffer neptuno=new StringBuffer(); 
     neptuno.append("La Fuente de Neptuno es un monumento de estilo Neoclsico que ocupa el centro de la plaza de Cnovas del Castillo, en la ciudad espaola de Madrid. Fue diseada por el arquitecto Ventura Rodrguez en el ao 1782, y realizada entre 1780 y 1784 por Juan Pascual de Mena, quien la esculpi toda ella en mrmol blanco procedente de Montesclaros (Toledo)[cita requerida], como parte de las obras de ordenacin del Saln del Prado. Forma parte, pues, de un programa iconogrfico inspirado en la mitologa grecorromana.Caractersticas" +
     		"La fuente consiste en un gran piln circular en cuyo centro se encuentra la figura de Neptuno, dios de los mares, con una culebra enroscada en la mano derecha y el tridente en la izquierda, erguida sobre un carro formado por una concha tirada por dos caballos marinos con cola de pez (hipocampos). Alrededor del carro se ven focas y delfines que arrojan agua a gran altura. El dios de las aguas aludira a la Marina que Carlos III reform para hacerla ms competitiva y reforzar el nexo con las colonias." +
     		"La fuente, que en un principio estuvo situada en el extremo del Prado de Apolo, mirando a la fuente de Cibeles, fue trasladada al centro de la plaza de Cnovas del Castillo en 1898, lugar en donde sigue actualmente. Forma parte, junto con la Cibeles, y la Fuente de Apolo o de las Cuatro Estaciones de los tres grandes grupos escultricos diseados por Ventura Rodrguez para el Saln del Prado.");
	
		
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('Museo Del Prado',-3.692386,40.413858,'pre_elprado','Considerado el noveno museo del mundo por importancia. Reune una amplia coleccin del realismo espaol con Velazquez, Goya, Rubens o Murillo a la cabeza.','"+prado.toString()+"',1);");
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('Sol',-3.703333,40.416876,'pre_sol','La puerta del sol es un smbolo de la capital. Lugar tradicional de reunin y celebracin de fin de ao.','"+sol.toString()+"',2);");
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('Cibeles',-3.692622,40.419225,'pre_cibeles','La diosa Cibeles','"+cibeles.toString()+"',2);");
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('Neptuno',-3.69416667,40.41524167,'pre_neptuno','El dios Neptuno','"+neptuno.toString()+"',2);");
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('Palacio Real',-3.71427222,40.41853055,'pre_palacio_real','Es la residencia oficial del Rey de Espaa. Utilizado en la prctica para actos oficiales, permite al visitante un recorrido por algunas de sus estancias.','"+palacio.toString()+"',2);");
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('Museo Thyssen-Bornemisza',-3.69499167,40.41635278,'pre_thyssen','El Museo Thyssen-Bornemisza ofrece al pblico un recorrido por el arte, desde el siglo XIII hasta las postrimeras del siglo XX.','Descripcion larga',1);");
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('Museo Reina Sofia',-3.69422222,40.40821667,'pre_reina_sofia','El Museo Nacional Centro de Arte Reina Sofa (MNCARS) es el museo nacional espaol de arte del siglo XX y actual.','Descripcion larga',1);");
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('Museo Sorolla',-3.69253333,40.43514167,'pre_sorolla','','Descripcion larga',1);");		
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('El Retiro',-3.68316389,40.41718333,'pre_retiro','','"+elretiro.toString()+"',2);");		
		
		
		//
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('Sitio1',-3.69819615,40.41524160,'pre_neptuno','Mi Sitio de prueba 1','Mi Sitio de prueba 1',4);");
		db.execSQL("insert into POI (nombre,longitud,latitud,imagen,desc_breve,desc_larga,tipo_punto) values ('Sitio2',-3.69100367,40.41524162,'pre_neptuno','Mi Sitio de prueba 2','Mi Sitio de prueba 2',4);");
		*/
		
		Log.d("Guia","Se ha recreado el modelo correctamente CON descripciones largas y sitios personalizados");
		
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int version, int newVersion) {
		Log.d("Guia","Existe un cambio de versin en BBDD. Preparado para actualizar.");
		
		// TODO Auto-generated method stub
		 db.execSQL("DROP TABLE IF EXISTS "+TIPO_POI);
		 db.execSQL("DROP TABLE IF EXISTS "+POI);
		 db.execSQL("DROP TABLE IF EXISTS "+GALERIA);
		 
		 Log.d("DEBUG","Base de datos borrada");
		 
		 onCreate(db);
	}
	
}
