package es.guia.db.adapters;

import java.util.*;

import android.content.ContentValues;
import android.content.Context;

import es.guia.db.*;
import es.guia.beans.*;
import android.database.*;
import android.database.sqlite.*;
import android.util.Log;

public class POIAdapter {
	
	//Declaracin de campos de la entidad POI
	
	final String ID = "ID";
	final String NOMBRE = "NOMBRE";
	final String LONGITUD = "LONGITUD";
	final String LATITUD = "LATITUD";
	final String TIPO_POI = "TIPO_POI";
	final String IMAGEN = "IMAGEN";
	final String DESC_BREVE="DESC_BREVE";
	final String DESC_LARGA="DESC_LARGA";
	final String PRECIO="PRECIO";
	final String HORARIO="HORARIO";
	
	final String DATABASE_TABLE="POI";
	
	//
	private GuiaDatabaseHelper guiaDatabaseHelper;
	private SQLiteDatabase db;
	private Context context;
	
	
	public POIAdapter(Context context){
		this.context=context;
		open();
		Log.i("Guia", "Conexin lista para ser utilizada");
	}
	
	
	
	public POIAdapter open() throws SQLException{
		guiaDatabaseHelper=new GuiaDatabaseHelper(context);
		db=guiaDatabaseHelper.getWritableDatabase();
		
		return this;
	}
	
	public void close() throws SQLException{
		db.close();
		guiaDatabaseHelper.close();
	}
	
	public long insertUserPOI(POI poi) throws SQLException{
		 return insert(poi.getNombre(),poi.getLongitud(),poi.getLatitud(),poi.getImagen(),poi.getDesc_breve(),poi.getDesc_breve(),poi.getTipoPOI(),"","");
		
	}
	
	public long insert(String nombre, String longitud, String latitud, String imagen, String descBreve, String descLarga,String tipo,String precio, String horario) throws SQLException{
		ContentValues content=createContent(nombre,longitud,latitud,imagen,descBreve,descLarga,tipo,precio,horario);
		return db.insert(DATABASE_TABLE, null, content);
	}
	
	public long delete(POI poi) throws SQLException{
		Log.d("Guia","Borrando el punto de usuario con id: "+poi.getId());
		String[] params={poi.getId()};
		return db.delete(DATABASE_TABLE, "id=?", params);
	}
	
	/*
	 * Obtiene una lista de puntos de un tipo determinado.
	 * 
	 * @param type - Tipo a recuperar
	 * @return List - Lista de puntos recuperados
	 */
	
	public List<POI> getPOIsByType(String type) throws SQLException{
		Log.i("[GUIA]","Recuperando los puntos de inters");
		String[] params={type};
		
		Cursor cursor=db.query(DATABASE_TABLE, new String[]{ID,NOMBRE,LONGITUD,LATITUD,IMAGEN,DESC_BREVE,TIPO_POI}, "tipo_poi=?", params, null, null, null);
		List<POI> listaPOIs=new ArrayList<POI>();
		
		if(!cursor.moveToFirst()) return listaPOIs;
		
		do{
			String id=cursor.getString(0);
			String nombre=cursor.getString(1);
			String longitud=cursor.getString(2);
			String latitud=cursor.getString(3);
			String imagen=cursor.getString(4);
			String desc_breve=cursor.getString(5);
			String tipo=cursor.getString(6);
			
			POI poi=new POI(id,nombre,longitud,latitud,tipo);
			poi.setImagen(imagen);
			poi.setDesc_breve(desc_breve);
			
			
			listaPOIs.add(poi);
			
			Log.d("POIAdapter", "Aadiendo "+nombre+" a la lista");
		
		}while(cursor.moveToNext());
		
		cursor.close();
			
		Log.i("[GUIA]","La lista de puntos de inters se ha generado correctamente.");
		
		return listaPOIs;
	}
	

	
	public List<POI> getAllPOIs() throws SQLException{
		Log.i("[GUIA]","Recuperando los puntos de inters");
		String[] params={"4"};
		
		Cursor cursor=db.query(DATABASE_TABLE, new String[]{ID,NOMBRE,LONGITUD,LATITUD,IMAGEN,DESC_BREVE,TIPO_POI}, "tipo_POI<>?", params, null, null, null);
		List<POI> listaPOIs=new ArrayList<POI>();
		
		if(!cursor.moveToFirst()) return listaPOIs;
		
		do{
			String id=cursor.getString(0);
			String nombre=cursor.getString(1);
			String longitud=cursor.getString(2);
			String latitud=cursor.getString(3);
			String imagen=cursor.getString(4);
			String desc_breve=cursor.getString(5);
			String tipo=cursor.getString(6);
			
			POI poi=new POI(id,nombre,longitud,latitud,tipo);
			poi.setImagen(imagen);
			poi.setDesc_breve(desc_breve);
			
			
			listaPOIs.add(poi);
			
			Log.d("POIAdapter", "Aadiendo "+nombre+" a la lista");
		
		}while(cursor.moveToNext());
		
		cursor.close();
			
		Log.i("[GUIA]","La lista de puntos de inters se ha generado correctamente.");
		
		return listaPOIs;
		
		
	}
	
	/*
	 * Devuelve todos los puntos registrados por el usuario.
	 */
	
	public List<POI> getAllUserPOIs() throws SQLException{
		Log.i("[GUIA]","Recuperando los puntos de inters de usuario");
		
		String[] params=new String[]{"4"};
		
		Cursor cursor=db.query(DATABASE_TABLE, new String[]{ID,NOMBRE,LONGITUD,LATITUD,IMAGEN,DESC_BREVE,DESC_LARGA,TIPO_POI}, "tipo_poi=?", params, null, null, null);
		List<POI> listaPOIs=new ArrayList<POI>();
		
		if(!cursor.moveToFirst()) return listaPOIs;
		
		do{
			String id=cursor.getString(0);
			String nombre=cursor.getString(1);
			String longitud=cursor.getString(2);
			String latitud=cursor.getString(3);
			String imagen=cursor.getString(4);
			String desc_breve=cursor.getString(5);
			String desc_larga=cursor.getString(6);
			String tipo=cursor.getString(7);
			
			POI poi=new POI(id,nombre,longitud,latitud,tipo);
			poi.setImagen(imagen);
			poi.setDesc_breve(desc_breve);
			poi.setDesc_larga(desc_larga);
			
			
			listaPOIs.add(poi);
			
			Log.d("POIAdapter", "Aadiendo punto de usuario "+nombre+" a la lista");
		
		}while(cursor.moveToNext());
		
		cursor.close();
		
			
		Log.i("[GUIA]","La lista de puntos de inters se ha generado correctamente.");
		
		return listaPOIs;
		
		
	}
	
	
	/**
	* Consulta el punto de inters por identificador.
	*
	*/
	
	public POI getPOI(String id) throws SQLException{
		Log.d("[POIAdapter]","Consultando el punto con id: "+id);
		
		String[] params=new String[]{id};
		
		POI poi=null;
		Cursor cursor=db.query(DATABASE_TABLE, new String[]{ID,NOMBRE,LONGITUD,LATITUD,IMAGEN,DESC_BREVE,DESC_LARGA,TIPO_POI,PRECIO,HORARIO}, "id=?", params, null, null, null);
		
		if(cursor.moveToFirst()){
			
			String nombre=cursor.getString(1);
			String longitud=cursor.getString(2);
			String latitud=cursor.getString(3);
			String imagen=cursor.getString(4);
			String desc_breve=cursor.getString(5);
			String desc_larga=cursor.getString(6);
			String tipo=cursor.getString(7);
			String precio=cursor.getString(8);
			String horario=cursor.getString(9);
			
			poi=new POI(id,nombre,longitud,latitud,tipo);
			poi.setImagen(imagen);
			poi.setDesc_breve(desc_breve);
			poi.setDesc_larga(desc_larga);
			poi.setPrecio(precio);
			poi.setHorario(horario);
		}
		
		cursor.close();
		close();
		
		return poi;
			
	}
	
	
	
	/**
	 * Crea un ContentValue para operar con los mtodos CRUD de este adaptador.
	 */
	
	private ContentValues createContent(String nombre, String longitud, String latitud, String imagen, String descBreve, String descLarga, String tipo, String precio, String horario){
		ContentValues content = new ContentValues();
		content.put("NOMBRE", nombre);
		content.put("LONGITUD", longitud);
		content.put("LATITUD",latitud);
		content.put("IMAGEN",imagen);
		content.put("DESC_BREVE",descBreve);
		content.put("DESC_LARGA",descLarga);
		content.put("TIPO_POI", tipo);
		content.put("PRECIO", precio);
		content.put("HORARIO",horario);
		
		return content;
		
	}
	
	private ContentValues createContent(String id){
		ContentValues content=new ContentValues();
		content.put("ID",id);
		
		return content;
	}
	

}
