package es.guia.db.adapters;

import java.util.*;
import android.content.Context;

import es.guia.db.*;
import es.guia.beans.*;
import android.database.*;
import android.database.sqlite.*;
import android.util.Log;

public class TipoPOIAdapter {
	
	//Declaracin de campos de la entidad TipoPOI
	
	public static final String ID = "ID";
	public static final String NOMBRE = "NOMBRE";
	
	
	final String DATABASE_TABLE="TIPO_POI";
	
	//
	private GuiaDatabaseHelper guiaDatabaseHelper;
	private SQLiteDatabase db;
	private Context context;
	
	
	public TipoPOIAdapter(Context context){
		this.context=context;
		open();
		Log.i("Guia", "Conexin lista para ser utilizada");
	}
	
	
	
	public TipoPOIAdapter open() throws SQLException{
		guiaDatabaseHelper=new GuiaDatabaseHelper(context);
		db=guiaDatabaseHelper.getWritableDatabase();
		
		return this;
	}
	
	public void close() throws SQLException{
		db.close();
		guiaDatabaseHelper.close();
	}
	
	
	
	
	/**
	 * Obtiene la lista completa de tipos de puntos de inters.
	 * @return List<TipoPOI> - Lista de tipos de punto
	 */

	
	public List<TipoPOI> getAllTypes() throws SQLException{
		Log.i("[GUIA]","Recuperando los tipos punto de inters");
		
		Cursor cursor=db.query(DATABASE_TABLE, new String[]{ID,NOMBRE}, null, null, null, null, null);
		List<TipoPOI> listaPOIs=new ArrayList<TipoPOI>();
		
		
		if(!cursor.moveToNext()) return listaPOIs;
		do{
			String id=cursor.getString(0);
			String nombre=cursor.getString(1);
			
			TipoPOI tipo=new TipoPOI();	
			tipo.setId(id);
			tipo.setNombre(nombre);
			
			listaPOIs.add(tipo);
			
			Log.d("TipoPOIAdapter", "Aadiendo "+nombre+" a la lista");
		}while(cursor.moveToNext());
		
		cursor.close();
			
		Log.i("[GUIA]","La lista de puntos de inters se ha generado correctamente.");
		
		return listaPOIs;
	}
	

	
	
	/**
	* Consulta el punto de inters por identificador.
	*
	*/
	
	public TipoPOI getTipoPOI(String id) throws SQLException{
		Log.d("[POIAdapter]","Consultando el punto con id: "+id);
		
		String[] params=new String[]{id};
		
		TipoPOI tipo=null;
		Cursor cursor=db.query(DATABASE_TABLE, new String[]{NOMBRE}, "id=?", params, null, null, null);
		
		if(cursor.moveToFirst()){
			
			String nombre=cursor.getString(1);
			
			tipo=new TipoPOI();
			tipo.setId(id);
			tipo.setNombre(nombre);
		}
		
		cursor.close();
		close();
		
		return tipo;
			
	}
}
