package es.guia.maps.gps;

import com.google.android.maps.GeoPoint;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;
import com.google.android.maps.Overlay;
import com.google.android.maps.OverlayItem;

import es.guia.beans.POI;
import es.guia.db.adapters.POIAdapter;
import es.guia.interfaz.Menus;
import es.guia.interfaz.R;
import android.content.Context;
import android.graphics.drawable.Drawable;
import android.location.*;
import android.os.Bundle;
import android.util.Log;
import android.widget.Toast;
import android.app.*;

import es.guia.beans.*;
import es.guia.db.*;
import es.guia.db.adapters.*;

import java.util.*;

import es.guia.maps.overlay.*;

public class GeoUpdateHandler implements LocationListener {
	private MapController mapController;
	private GeoPoint position;
	private MapView mapView;
	private List<Overlay> mapOverlays;
	private OverlayItem userItem,placeItem;
	private UserOverlay userPicOverlay;
	private PlacesOverlay markerOverlay;
	private Context mContext;
	private Activity actividad;
	
	public GeoUpdateHandler(Context mContext, MapController mapController, MapView mapView, List<Overlay>mapOverlays, Activity actividad){
		this.mapController = mapController;
		this.mapView = mapView;
		this.mapOverlays=mapOverlays;
		this.mContext=mContext;
		this.actividad=actividad;
		
	}
	
	public GeoUpdateHandler(Activity actividad){
		this.actividad=actividad;
	}

	public void onLocationChanged(Location location) {
		double lat = location.getLatitude();
		double lng= location.getLongitude();
		position = new GeoPoint((int)(lat*1E6),(int)(lng*1E6));
		
		mapOverlays=mapView.getOverlays();
		mapOverlays.clear();
		
		
		mapController.setCenter(position);
		mapController.setZoom(17);
		mapController.animateTo(position);
		mapView.setBuiltInZoomControls(true);
		
		//Obtencin de direccin postal
		Location loc=getCurrentLocation();
	    Geocoder geoCoder=new Geocoder(mContext);
	    String calle="No disponible";
	     try{
	    	 List<Address> direccion=geoCoder.getFromLocation(loc.getLatitude(), loc.getLongitude(), 1);
	    	 if(direccion.size()!=0) calle=direccion.get(0).getAddressLine(0)+","+direccion.get(0).getAddressLine(1);
	    	 Log.d("Guia",calle);
	     }catch(Exception e){Log.e("Guia",e.toString());}
		
		 List<Overlay> mapOverlays = mapView.getOverlays();    
	     UserItemizedOverlay itemizedoverlay = new UserItemizedOverlay(mContext.getResources().getDrawable(R.drawable.persona2),mContext,calle);
	     
	     
	     
	     //Listado de items del mapa
	     
	     //Item del usuario
	     OverlayItem dondeEstoy=new OverlayItem(position,"Su posicion:",calle); 
	     itemizedoverlay.addOverlay(dondeEstoy);
	        
	        //Recuperacin de puntos de inters.
	        
	        TipoPOIAdapter tipoAdapter=new TipoPOIAdapter(actividad);
	        List<TipoPOI> listaTipos=tipoAdapter.getAllTypes();
	        
	        Log.d("GeoUpdateHandler","Antes de la consulta a los tipos de punto");
	        
	        POIAdapter poiAdapter=new POIAdapter(actividad);
	        poiAdapter.open();
        	List<POI> listaPOI=poiAdapter.getAllPOIs();
        	
        	Log.d("GeoUpdateHandler","Consulto los tipos de punto: "+listaTipos.size());
	        
	        for(int k=0;k<listaTipos.size();k++){
	        	Log.d("GeoUpdateHandler","===========================");
	        	TipoPOI tipoPOI=listaTipos.get(k);
	        	
	        	Log.d("GeoUpdateHandler",tipoPOI.getId());
	        	Log.d("GeoUpdateHandler",tipoPOI.getNombre());
	        	
	        	
	        	poiAdapter=new POIAdapter(actividad);
	        	listaPOI=poiAdapter.getPOIsByType(tipoPOI.getId()); 
	        	Log.d("GeoUpdateHandler","Consultar por tipo: "+tipoPOI.getId());
	        	
	        	if(listaPOI.size()==0) continue;
	        	
	        	//Generacin de items de punto de inters
	        	String nombreTipo=tipoPOI.getNombre().toLowerCase();
	        	PlacesItemizedOverlay poiOverlay= new PlacesItemizedOverlay(mContext.getResources().getDrawable(Menus.hImagenes.get(nombreTipo)),mContext,actividad);
	        	
	        	for(int i=0;i<listaPOI.size();i++){
	        		POI p=listaPOI.get(i);
	        		Log.d("GeoUpdateHandler",p.getNombre());
	        		PlacesOverlay nuevoPunto=new PlacesOverlay(new GeoPoint((int)(Double.parseDouble(p.getLatitud())*1E6),(int)(Double.parseDouble(p.getLongitud())*1E6)),p.getTipoPOI(),p.getNombre(),p);
	        		poiOverlay.addOverlay(nuevoPunto);
	        	}
	        	
	        	mapOverlays.add(poiOverlay);
	        }
	        
	        tipoAdapter.close();
	        poiAdapter.close();
	        
	        //Aadir al mapa las distintas listas de puntos
	        mapOverlays.add(itemizedoverlay);
	}
	
	
	public void onProviderDisabled(String arg0) {
		Toast.makeText(mContext,"GPS Desactivado", Toast.LENGTH_SHORT).show();
	}

	public void onProviderEnabled(String arg0) {
		Toast.makeText(mContext,"GPS Activado", Toast.LENGTH_SHORT).show();

	}

	public void onStatusChanged(String arg0, int arg1, Bundle arg2) {
		Toast.makeText(mContext,"GPS Cambio de estado", Toast.LENGTH_SHORT).show();

	}
	
	/**
	 * Devuelve la localizacin actual en coordenadas geogrficas
	 * @return Location
	 */
	public Location getCurrentLocation(){
		 //Calculo posicin actual
        LocationManager locationManager = (LocationManager) actividad.getSystemService(Context.LOCATION_SERVICE);
        
      //Posicin actual
		Criteria criteria=new Criteria();
		String bestProvider=locationManager.getBestProvider(criteria, true);
		Location loc=locationManager.getLastKnownLocation(bestProvider);
		
		return loc;
	}
	
}