package es.guia.maps.overlay;


import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.util.Log;
import android.view.*;
import android.widget.*;


import com.google.android.maps.*;

import es.guia.beans.*;
import es.guia.interfaz.*;

import java.util.*;

public class PlacesItemizedOverlay extends ItemizedOverlay<PlacesOverlay>{
	
	private ArrayList<PlacesOverlay> mOverlays = new ArrayList<PlacesOverlay>();
	private Context mContext=null;
	private Activity actividad=null;

	public PlacesItemizedOverlay(Drawable arg0) {
		super(boundCenterBottom(arg0));
	}
	
	public PlacesItemizedOverlay(Drawable defaultMarker, Context context, Activity actividad) {
		  super(boundCenterBottom(defaultMarker));
		  mContext = context;
		  this.actividad= actividad;
	}

	@Override
	protected PlacesOverlay createItem(int i) {
		return (PlacesOverlay)mOverlays.get(i);
	}

	@Override
	public int size() {
		return mOverlays.size();
	}
	
	public void addOverlay(PlacesOverlay overlay) {
	    mOverlays.add(overlay);
	    populate();
	}
	
	@Override
	protected boolean onTap(int index) {
		PlacesOverlay item =(PlacesOverlay) mOverlays.get(index);
		POI poi=item.getPOI();
		
        AlertDialog.Builder builder;
        AlertDialog alertDialog;

        LayoutInflater inflater = (LayoutInflater) mContext.getSystemService(Activity.LAYOUT_INFLATER_SERVICE);
        View layout = inflater.inflate(R.layout.info_previa,
                                       (ViewGroup) actividad.findViewById(R.id.layout_root));
        
        
        TextView text = (TextView) layout.findViewById(R.id.text);
        text.setText(poi.getDesc_breve());
        
        ImageView image = (ImageView) layout.findViewById(R.id.image);
        image.setImageResource(Menus.hImagenes.get(poi.getImagen()));
        
        builder = new AlertDialog.Builder(mContext);
        builder.setView(layout);
        
        //Manejador de opciones
        
        OpcionesHandler oHandler=new OpcionesHandler(poi,actividad);
        
        builder.setPositiveButton("Llegar",oHandler);
        
        
        builder.setNeutralButton("+Info",oHandler);
        builder.setNegativeButton("Cancelar",oHandler);	
        
        alertDialog = builder.create(); 
        
        alertDialog.setTitle(poi.getNombre());
        alertDialog.show();
		
		
	  return true;
	}
	
	
	/**
	 * Se encarga de manejar las opciones de los botones de la ventana de dialog.
	 * @author Daniel Corts
	 *
	 */
	
	class OpcionesHandler implements DialogInterface.OnClickListener{
		
		public static final int LLEGAR=-1;
		public static final int CANCEL=-2;
		public static final int INFO=-3;
		
		
		private POI poi;
		private Activity actividad;
		
		public OpcionesHandler(POI poi, Activity actividad){
			super();
			this.poi=poi;
			this.actividad=actividad;
			
		}

		public void onClick(DialogInterface dialog, int id) {
			
			Log.d("Id: ",String.valueOf(id));
			Intent intento=null;
			
			switch(id){
				case LLEGAR:
					Log.d("Longitud: ",poi.getLongitud());
					Log.d("Latitud: ",poi.getLatitud());
					
					intento=new Intent(actividad, CalculoRuta.class);
						
					intento.putExtra("longitudDestino", poi.getLongitud());
					intento.putExtra("latitudDestino", poi.getLatitud());
					
					actividad.startActivity(intento);
					
					break;
				case INFO:
					Log.d("+Info","Mas informacion");
					intento=new Intent(actividad, DescripcionPOI.class);
					
					intento.putExtra("id",poi.getId());
					
					actividad.startActivity(intento);
					break;
				default:
					dialog.cancel();
			}
			
		}
		
	}
	
}
